@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -34,23 +34,21 @@
 #define ASC_TYPE_GLOBALS (asc_globals_get_type ())
 G_DECLARE_DERIVABLE_TYPE (AscGlobals, asc_globals, ASC, GLOBALS, GObject)
 
-struct _AscGlobalsClass
-{
+struct _AscGlobalsClass {
 	GObjectClass parent_class;
 };
 
-typedef struct
-{
-	gboolean	use_optipng;
-	gchar		*optipng_bin;
-	gchar		*ffprobe_bin;
-	gchar		*tmp_dir;
+typedef struct {
+	gboolean use_optipng;
+	gchar *optipng_bin;
+	gchar *ffprobe_bin;
+	gchar *tmp_dir;
 
-	GMutex		pangrams_mutex;
-	GPtrArray	*pangrams_en;
+	GMutex pangrams_mutex;
+	GPtrArray *pangrams_en;
 
-	GMutex		hint_tags_mutex;
-	GHashTable	*hint_tags;
+	GMutex hint_tags_mutex;
+	GHashTable *hint_tags;
 } AscGlobalsPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AscGlobals, asc_globals, G_TYPE_OBJECT)
@@ -73,14 +71,17 @@ asc_compose_error_quark (void)
 	return quark;
 }
 
-static GObject*
-asc_globals_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties)
+static GObject *
+asc_globals_constructor (GType type,
+			 guint n_construct_properties,
+			 GObjectConstructParam *construct_properties)
 {
 	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&g_globals_mutex);
 	if (g_globals != NULL)
 		return G_OBJECT (g_globals);
 	else
-		return G_OBJECT_CLASS (asc_globals_parent_class)->constructor (type, n_construct_properties, construct_properties);
+		return G_OBJECT_CLASS (asc_globals_parent_class)
+		    ->constructor (type, n_construct_properties, construct_properties);
 }
 
 static void
@@ -135,7 +136,7 @@ asc_globals_class_init (AscGlobalsClass *klass)
 	object_class->finalize = asc_globals_finalize;
 }
 
-static AscGlobalsPrivate*
+static AscGlobalsPrivate *
 asc_globals_get_priv (void)
 {
 	return GET_PRIVATE (g_object_new (ASC_TYPE_GLOBALS, NULL));
@@ -162,7 +163,7 @@ asc_globals_clear (void)
  *
  * Get temporary directory used by appstream-compose.
  **/
-const gchar*
+const gchar *
 asc_globals_get_tmp_dir (void)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -175,7 +176,7 @@ asc_globals_get_tmp_dir (void)
  * Get temporary directory used by appstream-compose
  * and try to create it if it does not exist.
  **/
-const gchar*
+const gchar *
 asc_globals_get_tmp_dir_create (void)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -230,7 +231,7 @@ asc_globals_set_use_optipng (gboolean enabled)
  *
  * Get path to the "optipng" binary we should use.
  **/
-const gchar*
+const gchar *
 asc_globals_get_optipng_binary (void)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -257,7 +258,7 @@ asc_globals_set_optipng_binary (const gchar *path)
  *
  * Get path to the "ffprobe" binary we should use.
  **/
-const gchar*
+const gchar *
 asc_globals_get_ffprobe_binary (void)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -285,7 +286,7 @@ asc_globals_set_ffprobe_binary (const gchar *path)
  *
  * Returns: (transfer none) (element-type utf8): List of pangrams.
  */
-GPtrArray*
+GPtrArray *
 asc_globals_get_pangrams_for (const gchar *lang)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -306,16 +307,16 @@ asc_globals_get_pangrams_for (const gchar *lang)
 
 		/* load array from resources */
 		data = g_resource_lookup_data (asc_get_resource (),
-						"/org/freedesktop/appstream-compose/pangrams/en.txt",
-						G_RESOURCE_LOOKUP_FLAGS_NONE,
-						NULL);
+					       "/org/freedesktop/appstream-compose/pangrams/en.txt",
+					       G_RESOURCE_LOOKUP_FLAGS_NONE,
+					       NULL);
 		if (data == NULL)
 			return NULL;
 
 		strv = g_strsplit (g_bytes_get_data (data, NULL), "\n", -1);
 		if (strv == NULL)
 			return NULL;
-		priv->pangrams_en = g_ptr_array_new_full(g_strv_length (strv), g_free);
+		priv->pangrams_en = g_ptr_array_new_full (g_strv_length (strv), g_free);
 		for (guint i = 0; strv[i] != NULL; i++)
 			g_ptr_array_add (priv->pangrams_en, g_strdup (strv[i]));
 	}
@@ -348,10 +349,12 @@ asc_globals_create_hint_tag_table (void)
 		const AscHintTagStatic s = asc_hint_tag_list[i];
 		htag = asc_hint_tag_new (s.tag, s.severity, s.explanation);
 		r = g_hash_table_insert (priv->hint_tags,
-							g_ref_string_new_intern (asc_hint_tag_list[i].tag),
-							htag);
+					 g_ref_string_new_intern (asc_hint_tag_list[i].tag),
+					 htag);
 		if (G_UNLIKELY (!r))
-			g_critical ("Duplicate compose-hint tag '%s' found in tag list. This is a bug in appstream-compose.", asc_hint_tag_list[i].tag);
+			g_critical ("Duplicate compose-hint tag '%s' found in tag list. This is a "
+				    "bug in appstream-compose.",
+				    asc_hint_tag_list[i].tag);
 	}
 
 	/* add validator issue hint tags */
@@ -359,9 +362,12 @@ asc_globals_create_hint_tag_table (void)
 		AscHintTag *htag;
 		gboolean r;
 		AsIssueSeverity severity;
-		g_autofree gchar *compose_tag = g_strconcat ("asv-", as_validator_issue_tag_list[i].tag, NULL);
-		g_autofree gchar *explanation = g_markup_printf_escaped ("<code>{{location}}</code> - <em>{{hint}}</em><br/>%s",
-									 as_validator_issue_tag_list[i].explanation);
+		g_autofree gchar *compose_tag = g_strconcat ("asv-",
+							     as_validator_issue_tag_list[i].tag,
+							     NULL);
+		g_autofree gchar *explanation = g_markup_printf_escaped (
+		    "<code>{{location}}</code> - <em>{{hint}}</em><br/>%s",
+		    as_validator_issue_tag_list[i].explanation);
 
 		/* any validator issue can not be of type error in as-compose - if the validation issue
 		 * is so severe that it renders the compose process impossible, we will throw another issue
@@ -375,7 +381,9 @@ asc_globals_create_hint_tag_table (void)
 					 g_ref_string_new_intern (compose_tag),
 					 htag);
 		if (G_UNLIKELY (!r))
-			g_critical ("Duplicate issue-tag '%s' found in tag list. This is a bug in appstream-compose.", as_validator_issue_tag_list[i].tag);
+			g_critical ("Duplicate issue-tag '%s' found in tag list. This is a bug in "
+				    "appstream-compose.",
+				    as_validator_issue_tag_list[i].tag);
 	}
 }
 
@@ -422,9 +430,7 @@ asc_globals_add_hint_tag (const gchar *tag,
 	}
 
 	htag = asc_hint_tag_new (tag, severity, explanation);
-	g_hash_table_insert (priv->hint_tags,
-			     g_ref_string_new_intern (tag),
-			     htag);
+	g_hash_table_insert (priv->hint_tags, g_ref_string_new_intern (tag), htag);
 	return TRUE;
 }
 
@@ -435,7 +441,7 @@ asc_globals_add_hint_tag (const gchar *tag,
  *
  * Returns: (transfer none): Hint tag details.
  */
-AscHintTag*
+AscHintTag *
 asc_globals_get_hint_tag_details (const gchar *tag)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
@@ -454,8 +460,8 @@ asc_globals_get_hint_tag_details (const gchar *tag)
  *
  * Returns: (transfer full): A list of valid hint tags. Free with %g_strfreev
  */
-gchar**
-asc_globals_get_hint_tags ()
+gchar **
+asc_globals_get_hint_tags (void)
 {
 	AscGlobalsPrivate *priv = asc_globals_get_priv ();
 	GHashTableIter iter;
@@ -468,10 +474,10 @@ asc_globals_get_hint_tags ()
 		asc_globals_create_hint_tag_table ();
 
 	/* deep-copy the table keys to a strv */
-	strv = g_new0 (gchar*, g_hash_table_size (priv->hint_tags) + 1);
+	strv = g_new0 (gchar *, g_hash_table_size (priv->hint_tags) + 1);
 	g_hash_table_iter_init (&iter, priv->hint_tags);
 	while (g_hash_table_iter_next (&iter, &key, NULL))
-		strv[i++] = g_strdup ((const gchar*) key);
+		strv[i++] = g_strdup ((const gchar *) key);
 
 	return strv;
 }
@@ -500,7 +506,7 @@ asc_globals_hint_tag_severity (const gchar *tag)
  *
  * Returns: An explanation template, or %NULL if the tag was not found.
  */
-const gchar*
+const gchar *
 asc_globals_hint_tag_explanation (const gchar *tag)
 {
 	AscHintTag *htag = asc_globals_get_hint_tag_details (tag);
