@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -550,6 +550,16 @@ void AppStream::Component::addProvided(const AppStream::Provided &provided)
     as_component_add_provided(d->cpt, provided.cPtr());
 }
 
+void Component::sortScreenshots(const QString &environment,
+                                const QString &style,
+                                bool prioritizeStyle)
+{
+    as_component_sort_screenshots(d->cpt,
+                                  qPrintable(environment),
+                                  qPrintable(style),
+                                  prioritizeStyle);
+}
+
 QList<Screenshot> Component::screenshotsAll() const
 {
     QList<Screenshot> res;
@@ -698,6 +708,11 @@ QHash<QString, QString> AppStream::Component::custom() const
     return result;
 }
 
+QString AppStream::Component::customValue(const QString &key) const
+{
+    return valueWrap(as_component_get_custom_value(d->cpt, qPrintable(key)));
+}
+
 QString AppStream::Component::customValue(const QString &key)
 {
     return valueWrap(as_component_get_custom_value(d->cpt, qPrintable(key)));
