@@ -23,18 +23,27 @@
 #include <QStringList>
 #include "appstreamqt_export.h"
 
-namespace AppStream {
+namespace AppStream
+{
+
+namespace SPDX
+{
 
-namespace SPDX {
 APPSTREAMQT_EXPORT bool isLicenseId(const QString &license_id);
+APPSTREAMQT_EXPORT bool isLicenseExceptionId(const QString &exception_id);
 APPSTREAMQT_EXPORT bool isLicenseExpression(const QString &license);
+
 APPSTREAMQT_EXPORT bool isMetadataLicense(const QString &license);
+APPSTREAMQT_EXPORT bool isFreeLicense(const QString &license);
 
 APPSTREAMQT_EXPORT QStringList tokenizeLicense(const QString &license);
 APPSTREAMQT_EXPORT QString detokenizeLicense(const QStringList &license_tokens);
 
 APPSTREAMQT_EXPORT QString asSpdxId(const QString &license);
 
+APPSTREAMQT_EXPORT QString licenseName(const QString &license);
+APPSTREAMQT_EXPORT QString licenseUrl(const QString &license);
+
 }
 
 }
