@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2018-2023 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2018-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -169,12 +169,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 
 	{ "cid-missing-affiliation-kde",
 	  AS_ISSUE_SEVERITY_WARNING,
-	  N_("The component is part of the KDE project, but its ID does not start with KDEs reverse-DNS name (\"org.kde\").")
+	  N_("The component is part of the KDE project, but its ID does not start with KDE's reverse-DNS name (\"org.kde\").")
 	},
 
 	{ "cid-missing-affiliation-gnome",
 	  AS_ISSUE_SEVERITY_INFO,
-	  N_("The component is part of the GNOME project, but its ID does not start with GNOMEs reverse-DNS name (\"org.gnome\").")
+	  N_("The component is part of the GNOME project, but its ID does not start with GNOME's reverse-DNS name (\"org.gnome\").")
 	},
 
 	{ "spdx-expression-invalid",
@@ -253,10 +253,18 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("There can only be one `source` image per screenshot and language.")
 	},
 
-	{ "screenshot-image-source-missing",
+	{ "screenshot-image-no-source",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
-	  N_("A screenshot must have at least one image of type `source`.")
+	  N_("A screenshot must have at least one untranslated image of type `source`.")
+	},
+
+	{ "screenshot-image-no-source-but-en-locale",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("A screenshot must have at least one untranslated image of type `source`, which could not be found. "
+	     "Instead, a tag with an `en` locale (`xml:lang=en`) was found, which is likely intended to be the "
+	     "translatable image. Please remove the XML localization attribute in this case.")
 	},
 
 	{ "screenshot-image-not-found",
@@ -400,7 +408,7 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	{ "relation-display-length-value-invalid",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("This `display_length` item contains an invalid display length. Its value must either be a shorthand string, or positive integer value denoting logical pixels. "
+	  N_("This `display_length` item contains an invalid display length. Its value must be a positive integer value denoting logical pixels. "
 	     "Please refer to the AppStream specification for more information on this tag.")
 	},
 
@@ -465,6 +473,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The component is missing a name (<name/> tag).")
 	},
 
+	{ "component-name-too-long",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The name of this component is excessively long and can likely not be displayed properly in most layouts.")
+	},
+
 	{ "component-summary-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("The component is missing a summary (<summary/> tag).")
@@ -505,6 +518,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The summary text does not start with a capitalized word, project name or number.")
 	},
 
+	{ "summary-too-long",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The summary text is very long, and will likely not be displayed properly everywhere.")
+	},
+
 	{ "icon-stock-cached-has-url",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -565,6 +583,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("An URL of this type has already been defined."),
 	},
 
+	{ "url-homepage-missing",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("This component is missing an `url` element of type `homepage` to link to the project's homepage."),
+	},
+
 	{ "developer-name-tag-deprecated",
 	  AS_ISSUE_SEVERITY_INFO,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
@@ -572,19 +596,37 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	     "`developer` block instead."),
 	},
 
+	{ "developer-info-missing",
+	  AS_ISSUE_SEVERITY_INFO,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("This component contains no `developer` element with information about its author."),
+	},
+
+	{ "developer-id-missing",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The `developer` element is missing an `id` property, containing a unique string ID for the developer. "
+	     "Consider adding a unique ID."),
+	},
+
+	{ "developer-id-invalid",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("The developer-ID is invalid. It should be an rDNS string identifying the developer, or a Fediverse handle. "
+	     "It must also only contain lowercase ASCII letters, numbers and punctuation."),
+	},
+
+	{ "developer-name-missing",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The `developer` block does not have a `name` element with a human-readable project author name."),
+	},
+
 	{ "developer-name-has-url",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("The `name` child of a `developer` block must not contain a hyperlink."),
 	},
 
-	{ "developer-id-missing",
-	  AS_ISSUE_SEVERITY_INFO,
-	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The `developer` element is missing an `id` property, containing a unique string ID for the developer. "
-		  "Consider adding a unique ID."),
-	},
-
 	{ "unknown-desktop-id",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("The set value is not an identifier for a desktop environment as registered with Freedesktop.org."),
@@ -743,13 +785,19 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The category name is not valid. Refer to the XDG Menu Specification for a list of valid category names."),
 	},
 
+	{ "all-categories-ignored",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("All categories for this component have been ignored, either because they were invalid or because they are of low quality "
+	     "(e.g. custom 'X-' prefixed or toolkit ones like 'GTK' or 'Qt'). Please fix your category names, or add more categories."),
+	},
+
 	{ "app-categories-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("This component is in no valid categories, even though it should be. Please check its metainfo file and desktop-entry file."),
 	},
 
 	{ "screenshot-caption-too-long",
-	  AS_ISSUE_SEVERITY_PEDANTIC,
+	  AS_ISSUE_SEVERITY_INFO,
 	  N_("The screenshot caption is too long (should be <= 100 characters)"),
 	},
 
@@ -1006,13 +1054,13 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	{ "content-rating-type-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The  `type` attribute of this `content_rating` element is missing or empty."),
+	  N_("The `type` attribute of this `content_rating` element is missing or empty."),
 	},
 
 	{ "content-rating-type-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The  `type` attribute of the `content_rating` element has a invalid value."),
+	  N_("The `type` attribute of the `content_rating` element has an invalid value."),
 	},
 
 	{ "content-rating-invalid-tag",
@@ -1024,13 +1072,13 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	{ "content-attribute-id-missing",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The  `id` attribute of the `content_attribute` element is missing or empty."),
+	  N_("The `id` attribute of the `content_attribute` element is missing or empty."),
 	},
 
 	{ "content-attribute-id-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
-	  N_("The  `id` attribute of the `content_attribute` element has a invalid value."),
+	  N_("The `id` attribute of the `content_attribute` element has an invalid value."),
 	},
 
 	{ "content-attribute-value-empty",
