@@ -24,7 +24,7 @@
 #include <config.h>
 #include <glib.h>
 
-#include "as-enums.h"
+#include "as-macros.h"
 
 /**
  * SECTION:as-vercmp
@@ -48,16 +48,15 @@ typedef struct AsVersion {
 static void
 as_version_parse (AsVersion *version, const gchar *v)
 {
-	const gchar *epoch_end = strchr(v, ':');
-	const gchar *version_end = strrchr(v, '-');
-	const gchar *complete_end = v + strlen(v);
+	const gchar *epoch_end = strchr (v, ':');
+	const gchar *version_end = strrchr (v, '-');
+	const gchar *complete_end = v + strlen (v);
 
 	version->epoch = (epoch_end == NULL) ? "" : v;
 	version->version = (epoch_end == NULL) ? v : epoch_end + 1;
 	version->version_end = (version_end == NULL) ? complete_end : version_end;
 	version->revision = (version_end == NULL) ? "0" : version_end + 1;
-	version->revision_end = ((version_end == NULL) ? version->revision + 1
-							: complete_end);
+	version->revision_end = ((version_end == NULL) ? version->revision + 1 : complete_end);
 }
 
 /**
@@ -73,14 +72,15 @@ as_version_parse (AsVersion *version, const gchar *v)
  * that it does not cause overflow.
  */
 static gint
-cmp_number (const gchar *a, const gchar *b, const gchar **pa,
-					    const gchar **pb)
+cmp_number (const gchar *a, const gchar *b, const gchar **pa, const gchar **pb)
 {
 	gint res = 0;
 	if (*a == '\0' && *b == '\0')
 		return 0;
-	for (; *a == '0'; a++);
-	for (; *b == '0'; b++);
+	for (; *a == '0'; a++)
+		;
+	for (; *b == '0'; b++)
+		;
 	for (; g_ascii_isdigit (*a) && g_ascii_isdigit (*b); a++, b++) {
 		if (res == 0 && *a != *b)
 			res = *a < *b ? -1 : 1;
@@ -103,8 +103,7 @@ cmp_number (const gchar *a, const gchar *b, const gchar **pa,
  * cmp_part:
  */
 static gint
-cmp_part (const gchar *a, const gchar *a_end,
-			  const gchar *b, const gchar *b_end)
+cmp_part (const gchar *a, const gchar *a_end, const gchar *b, const gchar *b_end)
 {
 	while (a != a_end || b != b_end) {
 		int cmpres;
@@ -124,7 +123,7 @@ cmp_part (const gchar *a, const gchar *a_end,
 				return (a == a_end) ? -1 : 1;
 			/* One non-digit part is shorter than the other one */
 			else if (g_ascii_isdigit (*a) != g_ascii_isdigit (*b))
-				return g_ascii_isdigit(*a) ? -1 : 1;
+				return g_ascii_isdigit (*a) ? -1 : 1;
 			/* Alpha looses against not alpha */
 			else if (g_ascii_isalpha (*a) != g_ascii_isalpha (*b))
 				return g_ascii_isalpha (*a) ? -1 : 1;
@@ -156,7 +155,7 @@ cmp_part (const gchar *a, const gchar *a_end,
  *	    <<0 if b is newer than a
  */
 gint
-as_vercmp (const gchar* a, const gchar *b, AsVercmpFlags flags)
+as_vercmp (const gchar *a, const gchar *b, AsVercmpFlags flags)
 {
 	AsVersion ver_a, ver_b;
 	gint res = 0;
@@ -186,19 +185,23 @@ as_vercmp (const gchar* a, const gchar *b, AsVercmpFlags flags)
 	as_version_parse (&ver_b, b);
 
 	if (G_UNLIKELY (ver_a.epoch != ver_b.epoch) &&
-		(!as_flags_contains (flags, AS_VERCMP_FLAG_IGNORE_EPOCH)) &&
-		(res = cmp_number (ver_a.epoch, ver_b.epoch, NULL, NULL)) != 0)
+	    (!as_flags_contains (flags, AS_VERCMP_FLAG_IGNORE_EPOCH)) &&
+	    (res = cmp_number (ver_a.epoch, ver_b.epoch, NULL, NULL)) != 0)
 		goto out;
-	else if ((res = cmp_part (ver_a.version, ver_a.version_end,
-				  ver_b.version, ver_b.version_end)) != 0)
+	else if ((res = cmp_part (ver_a.version,
+				  ver_a.version_end,
+				  ver_b.version,
+				  ver_b.version_end)) != 0)
 		goto out;
 	/* Optimizes for native version numbers (where revision is a string literal) */
 	else if (G_LIKELY (ver_a.revision != ver_b.revision) &&
-		(res = cmp_part (ver_a.revision, ver_a.revision_end,
-				 ver_b.revision, ver_b.revision_end)) != 0)
+		 (res = cmp_part (ver_a.revision,
+				  ver_a.revision_end,
+				  ver_b.revision,
+				  ver_b.revision_end)) != 0)
 		goto out;
 
-  out:
+out:
 	return res;
 }
 
@@ -214,7 +217,7 @@ as_vercmp (const gchar* a, const gchar *b, AsVercmpFlags flags)
  *	    <<0 if b is newer than a
  */
 gint
-as_vercmp_simple (const gchar* a, const gchar *b)
+as_vercmp_simple (const gchar *a, const gchar *b)
 {
 	return as_vercmp (a, b, AS_VERCMP_FLAG_NONE);
 }
@@ -259,23 +262,3 @@ as_vercmp_test_match (const gchar *ver1,
 		return FALSE;
 	}
 }
-
-/**
- * as_utils_compare_versions:
- *
- * Compare alpha and numeric segments of two versions.
- * The version compare algorithm is also used by RPM.
- *
- * Returns: 1: a is newer than b
- *	    0: a and b are the same version
- *	   -1: b is newer than a
- */
-gint
-as_utils_compare_versions (const gchar* a, const gchar *b)
-{
-	gint r;
-	r = as_vercmp (a, b, AS_VERCMP_FLAG_NONE);
-	if (r == 0)
-		return 0;
-	return (r < 0)? -1 : 1;
-}
